@@ -36,6 +36,7 @@ G_BEGIN_DECLS
 
 #define	EEL_TRASH_URI "trash:"
 #define EEL_DESKTOP_URI "x-nautilus-desktop:"
+#define EEL_SEARCH_URI "x-nautilus-search:"
 
 typedef void     (* EelReadFileCallback) (GnomeVFSResult result,
 					  GnomeVFSFileSize file_size,
@@ -66,24 +67,17 @@ gboolean           eel_uri_is_trash                      (const char           *
 gboolean           eel_uri_is_trash_folder               (const char           *uri);
 gboolean           eel_uri_is_in_trash                   (const char           *uri);
 gboolean           eel_uri_is_desktop                    (const char           *uri);
+gboolean           eel_uri_is_search                     (const char           *uri);
 
 
 char *             eel_format_uri_for_display            (const char           *uri);
-char *             eel_make_uri_from_input               (const char           *location);
-char *             eel_make_uri_from_input_with_trailing_ws (const char        *location);
-char *             eel_make_uri_from_shell_arg           (const char           *location);
 char *             eel_make_uri_canonical                (const char           *uri);
 char *             eel_make_uri_canonical_strip_fragment (const char           *uri);
 char *             eel_make_uri_from_half_baked_uri      (const char           *half_baked_uri);
 char *             eel_make_valid_utf8                   (const char           *name);
-gboolean           eel_uris_match                        (const char           *uri_1,
-							  const char           *uri_2);
 gboolean           eel_uris_match_ignore_fragments       (const char           *uri_1,
 							  const char           *uri_2);
 char *             eel_uri_get_basename                  (const char           *uri);
-char *             eel_uri_get_scheme                    (const char           *uri);
-char *             eel_uri_make_full_from_relative       (const char           *base_uri,
-							  const char           *uri);
 
 /* Convenience routine for simple file copying using text-based uris */
 GnomeVFSResult     eel_copy_uri_simple                   (const char           *source_uri,
